flexure Package
===============

:mod:`flexure` Package
----------------------

.. automodule:: landlab.components.flexure
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`flexure` Module
---------------------

.. automodule:: landlab.components.flexure.flexure
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`funcs` Module
-------------------

.. automodule:: landlab.components.flexure.funcs
    :members:
    :undoc-members:
    :show-inheritance:

